import setuptools

from itsimodels import __version__


with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='itsimodels',
    version=__version__,
    author='Splunk, Inc.',
    description='Model Definitions for Splunk IT Service Intelligence',
    long_description=long_description,
    long_description_content_type='text/markdown',
	url='https://github.com/splunk/itsi-models',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=2.7',
)



from itsimodels.correlation_search import *
from itsimodels.deep_dive import *
from itsimodels.entity_type import *
from itsimodels.glass_table import *
from itsimodels.glass_table_icon import *
from itsimodels.glass_table_image import *
from itsimodels.kpi_base_search import *
from itsimodels.kpi_threshold_template import *
from itsimodels.neap import *
from itsimodels.service import *
from itsimodels.service_analyzer import *
from itsimodels.service_template import *
from itsimodels.team import *
